pub fn filter_by_peer_version(
peers: &[(PeerId, ProtocolVersion)],
version: ProtocolVersion,
) -> Vec<PeerId>Expand description
Returns the subset of peers with the specified version.
pub fn filter_by_peer_version(
peers: &[(PeerId, ProtocolVersion)],
version: ProtocolVersion,
) -> Vec<PeerId>Returns the subset of peers with the specified version.